ARM Sunxi Platform Development
 help / color / mirror / Atom feed
* [PATCH v2 00/60] i2c: reword first drivers according to newest specification
@ 2024-07-06 11:20 Wolfram Sang
  2024-07-06 11:20 ` [PATCH v2 48/60] i2c: sun6i-p2wi: reword " Wolfram Sang
  2024-07-11 13:16 ` [PATCH v2 00/60] i2c: reword first drivers " Andi Shyti
  0 siblings, 2 replies; 6+ messages in thread
From: Wolfram Sang @ 2024-07-06 11:20 UTC (permalink / raw)
  To: linux-i2c
  Cc: Wolfram Sang, Ajay Gupta, Alain Volmat, Alexandre Torgue,
	Andi Shyti, Andreas Färber, Andrew Lunn,
	AngeloGioacchino Del Regno, asahi, Baolin Wang,
	Bartosz Golaszewski, Baruch Siach, Bence Csókás,
	Benson Leung, Binbin Zhou, Chen-Yu Tsai, Chris Brandt,
	Chris Packham, chrome-platform, Chunyan Zhang, Conghui Chen,
	Eddie James, Fabrizio Castro, Florian Fainelli, Gregory CLEMENT,
	Guenter Roeck, Hans de Goede, Hans Hu, Hector Martin,
	Heiko Stuebner, Jean Delvare, Jernej Skrabec, Jochen Friedrich,
	Jonathan Hunter, Kamal Dasu, Kunihiko Hayashi, linux-actions,
	linux-kernel, linux-mediatek, linux-mips, linuxppc-dev,
	linux-renesas-soc, linux-rockchip, linux-rpi-kernel, linux-stm32,
	linux-sunxi, linux-tegra, Manivannan Sadhasivam, Masami Hiramatsu,
	Matthias Brugger, Maxime Coquelin, Michael Ellerman,
	Michael Shych, openbmc, Orson Zhai, Patrice Chotard,
	Paul Cercueil, Peter Korsgaard, Pierre-Yves MORDRET, Ray Jui,
	Robert Richter, Samuel Holland, Scott Branden, Stefan Roese,
	Sven Peter, Thierry Reding, Thor Thayer, Till Harbaum,
	Vadim Pasternak, Viresh Kumar, virtualization, Vladimir Zapolskiy,
	Yicong Yang

Start changing the wording of the I2C main header wrt. the newest I2C
v7 and SMBus 3.2 specifications and replace "master/slave" with more
appropriate terms. This first step renames the members of struct
i2c_algorithm. Once all in-tree users are converted, the anonymous union
will go away again. All this work will also pave the way for finally
seperating the monolithic header into more fine-grained headers like
"i2c/clients.h" etc. So, this is not a simple renaming-excercise but
also a chance to update the I2C core to recent Linux standards.

Changes since v1:

* changed wording according to the terminology we agreed on and defined
  upstream. That means consistent use of "controller/target", and no
  more "host/client". I added "local/remote target" where necessary.
* added tags which I kept despite some changes in wording. The approach
  and code changes (if necessary) did not change.
* rebased to Andi's for-next branch
* this series only contains patches which convert the drivers fully. If
  all goes well, no more updates for them are needed. The previous
  series converted all users of "master_xfer". But to avoid tons of
  incremental patches to one driver, I will incrementally improve i2c.h
  and see which drivers can be fully converted step-by-step.
* do not mention I3C specs in commit messages, not really relevant here

Please note that I am not super strict with the 80 char limit. And, as
agreed, I did not convert occasions where old terminology is used in
register names or bits etc. or in function names outside of the I2C
realm.

The outcome is that before this series 115 drivers use old terminology,
after this only 54. Hooray.

And a comment to all janitors: Do not convert I2C drivers outside of
drivers/i2c yet. Let us first gain experience here and present the
well-tested results of what we figured out to other maintainers then.
This ensures they have to deal with way less patch revisions.

Thanks and happy hacking!


Wolfram Sang (60):
  i2c: reword i2c_algorithm according to newest specification
  i2c: ali15x3: reword according to newest specification
  i2c: altera: reword according to newest specification
  i2c: au1550: reword according to newest specification
  i2c: bcm-kona: reword according to newest specification
  i2c: bcm2835: reword according to newest specification
  i2c: brcmstb: reword according to newest specification
  i2c: cht-wc: reword according to newest specification
  i2c: cp2615: reword according to newest specification
  i2c: cros-ec-tunnel: reword according to newest specification
  i2c: davinci: reword according to newest specification
  i2c: digicolor: reword according to newest specification
  i2c: diolan-u2c: reword according to newest specification
  i2c: dln2: reword according to newest specification
  i2c: fsi: reword according to newest specification
  i2c: gpio: reword according to newest specification
  i2c: highlander: reword according to newest specification
  i2c: hisi: reword according to newest specification
  i2c: hix5hd2: reword according to newest specification
  i2c: i801: reword according to newest specification
  i2c: ibm_iic: reword according to newest specification
  i2c: iop3xx: reword according to newest specification
  i2c: isch: reword according to newest specification
  i2c: jz4780: reword according to newest specification
  i2c: kempld: reword according to newest specification
  i2c: ljca: reword according to newest specification
  i2c: lpc2k: reword according to newest specification
  i2c: ls2x: reword according to newest specification
  i2c: mlxcpld: reword according to newest specification
  i2c: mpc: reword according to newest specification
  i2c: mt7621: reword according to newest specification
  i2c: mv64xxx: reword according to newest specification
  i2c: ocores: reword according to newest specification
  i2c: octeon: reword according to newest specification
  i2c: opal: reword according to newest specification
  i2c: owl: reword according to newest specification
  i2c: pasemi: reword according to newest specification
  i2c: piix4: reword according to newest specification
  i2c: powermac: reword according to newest specification
  i2c: pxa-pci: reword according to newest specification
  i2c: riic: reword according to newest specification
  i2c: rk3x: reword according to newest specification
  i2c: robotfuzz-osif: reword according to newest specification
  i2c: rzv2m: reword according to newest specification
  i2c: sis5595: reword according to newest specification
  i2c: sprd: reword according to newest specification
  i2c: stm32f4: reword according to newest specification
  i2c: sun6i-p2wi: reword according to newest specification
  i2c: taos-evm: reword according to newest specification
  i2c: tegra-bpmp: reword according to newest specification
  i2c: thunderx-pcidrv: reword according to newest specification
  i2c: tiny-usb: reword according to newest specification
  i2c: uniphier-f: reword according to newest specification
  i2c: uniphier: reword according to newest specification
  i2c: viperboard: reword according to newest specification
  i2c: viai2c: reword according to newest specification
  i2c: nvidia-gpu: reword according to newest specification
  i2c: virtio: reword according to newest specification
  i2c: cpm: reword according to newest specification
  i2c: st: reword according to newest specification

 drivers/i2c/busses/i2c-ali15x3.c         |  2 +-
 drivers/i2c/busses/i2c-altera.c          |  4 +-
 drivers/i2c/busses/i2c-au1550.c          | 15 +++----
 drivers/i2c/busses/i2c-bcm-kona.c        | 13 +++---
 drivers/i2c/busses/i2c-bcm2835.c         | 10 ++---
 drivers/i2c/busses/i2c-brcmstb.c         | 11 +++--
 drivers/i2c/busses/i2c-cht-wc.c          |  8 ++--
 drivers/i2c/busses/i2c-cp2615.c          |  8 ++--
 drivers/i2c/busses/i2c-cpm.c             |  4 +-
 drivers/i2c/busses/i2c-cros-ec-tunnel.c  |  4 +-
 drivers/i2c/busses/i2c-davinci.c         | 17 ++++---
 drivers/i2c/busses/i2c-digicolor.c       |  6 +--
 drivers/i2c/busses/i2c-diolan-u2c.c      |  2 +-
 drivers/i2c/busses/i2c-dln2.c            |  4 +-
 drivers/i2c/busses/i2c-fsi.c             | 56 ++++++++++++------------
 drivers/i2c/busses/i2c-gpio.c            |  8 ++--
 drivers/i2c/busses/i2c-highlander.c      |  2 +-
 drivers/i2c/busses/i2c-hisi.c            |  8 ++--
 drivers/i2c/busses/i2c-hix5hd2.c         |  6 +--
 drivers/i2c/busses/i2c-i801.c            | 12 ++---
 drivers/i2c/busses/i2c-ibm_iic.c         | 27 +++++-------
 drivers/i2c/busses/i2c-iop3xx.c          | 15 +++----
 drivers/i2c/busses/i2c-isch.c            |  2 +-
 drivers/i2c/busses/i2c-jz4780.c          |  4 +-
 drivers/i2c/busses/i2c-kempld.c          |  4 +-
 drivers/i2c/busses/i2c-ljca.c            | 20 ++++-----
 drivers/i2c/busses/i2c-lpc2k.c           | 10 ++---
 drivers/i2c/busses/i2c-ls2x.c            | 11 +++--
 drivers/i2c/busses/i2c-mlxcpld.c         | 14 +++---
 drivers/i2c/busses/i2c-mpc.c             |  4 +-
 drivers/i2c/busses/i2c-mt7621.c          | 26 +++++------
 drivers/i2c/busses/i2c-mv64xxx.c         | 12 ++---
 drivers/i2c/busses/i2c-nvidia-gpu.c      |  7 ++-
 drivers/i2c/busses/i2c-ocores.c          |  8 ++--
 drivers/i2c/busses/i2c-octeon-core.c     |  6 +--
 drivers/i2c/busses/i2c-octeon-core.h     |  4 +-
 drivers/i2c/busses/i2c-octeon-platdrv.c  |  2 +-
 drivers/i2c/busses/i2c-opal.c            | 10 ++---
 drivers/i2c/busses/i2c-owl.c             | 12 ++---
 drivers/i2c/busses/i2c-pasemi-core.c     |  6 +--
 drivers/i2c/busses/i2c-piix4.c           |  2 +-
 drivers/i2c/busses/i2c-powermac.c        | 14 +++---
 drivers/i2c/busses/i2c-pxa-pci.c         |  2 +-
 drivers/i2c/busses/i2c-riic.c            |  8 ++--
 drivers/i2c/busses/i2c-rk3x.c            | 20 ++++-----
 drivers/i2c/busses/i2c-robotfuzz-osif.c  |  4 +-
 drivers/i2c/busses/i2c-rzv2m.c           | 12 ++---
 drivers/i2c/busses/i2c-sis5595.c         |  2 +-
 drivers/i2c/busses/i2c-sprd.c            | 16 +++----
 drivers/i2c/busses/i2c-st.c              |  8 ++--
 drivers/i2c/busses/i2c-stm32f4.c         |  8 ++--
 drivers/i2c/busses/i2c-sun6i-p2wi.c      | 20 ++++-----
 drivers/i2c/busses/i2c-taos-evm.c        |  2 +-
 drivers/i2c/busses/i2c-tegra-bpmp.c      |  4 +-
 drivers/i2c/busses/i2c-thunderx-pcidrv.c |  2 +-
 drivers/i2c/busses/i2c-tiny-usb.c        |  6 +--
 drivers/i2c/busses/i2c-uniphier-f.c      | 26 +++++------
 drivers/i2c/busses/i2c-uniphier.c        | 15 +++----
 drivers/i2c/busses/i2c-viai2c-common.c   |  2 +-
 drivers/i2c/busses/i2c-viai2c-wmt.c      |  8 ++--
 drivers/i2c/busses/i2c-viai2c-zhaoxin.c  | 12 ++---
 drivers/i2c/busses/i2c-viperboard.c      | 10 ++---
 drivers/i2c/busses/i2c-virtio.c          |  2 +-
 include/linux/i2c.h                      | 24 +++++++---
 64 files changed, 313 insertions(+), 320 deletions(-)

-- 
2.43.0


^ permalink raw reply	[flat|nested] 6+ messages in thread

* [PATCH v2 48/60] i2c: sun6i-p2wi: reword according to newest specification
  2024-07-06 11:20 [PATCH v2 00/60] i2c: reword first drivers according to newest specification Wolfram Sang
@ 2024-07-06 11:20 ` Wolfram Sang
  2024-07-06 11:43   ` Chen-Yu Tsai
  2024-07-11 10:26   ` Andi Shyti
  2024-07-11 13:16 ` [PATCH v2 00/60] i2c: reword first drivers " Andi Shyti
  1 sibling, 2 replies; 6+ messages in thread
From: Wolfram Sang @ 2024-07-06 11:20 UTC (permalink / raw)
  To: linux-i2c
  Cc: Wolfram Sang, Andi Shyti, Chen-Yu Tsai, Jernej Skrabec,
	Samuel Holland, linux-sunxi, linux-kernel

Change the wording of this driver wrt. the newest I2C v7 and SMBus 3.2
specifications and replace "master/slave" with more appropriate terms.

Signed-off-by: Wolfram Sang <wsa+renesas@sang-engineering.com>
---
 drivers/i2c/busses/i2c-sun6i-p2wi.c | 20 ++++++++++----------
 1 file changed, 10 insertions(+), 10 deletions(-)

diff --git a/drivers/i2c/busses/i2c-sun6i-p2wi.c b/drivers/i2c/busses/i2c-sun6i-p2wi.c
index 85e035e7a1d7..074eade6c4a4 100644
--- a/drivers/i2c/busses/i2c-sun6i-p2wi.c
+++ b/drivers/i2c/busses/i2c-sun6i-p2wi.c
@@ -10,7 +10,7 @@
  * The P2WI controller looks like an SMBus controller which only supports byte
  * data transfers. But, it differs from standard SMBus protocol on several
  * aspects:
  * - it supports only one slave device, and thus drop the address field
  * - it adds a parity bit every 8bits of data
  * - only one read access is required to read a byte (instead of a write
  *   followed by a read access in standard SMBus protocol)
@@ -88,7 +88,7 @@ struct p2wi {
 	void __iomem *regs;
 	struct clk *clk;
 	struct reset_control *rstc;
-	int slave_addr;
+	int target_addr;
 };
 
 static irqreturn_t p2wi_interrupt(int irq, void *dev_id)
@@ -121,7 +121,7 @@ static int p2wi_smbus_xfer(struct i2c_adapter *adap, u16 addr,
 	struct p2wi *p2wi = i2c_get_adapdata(adap);
 	unsigned long dlen = P2WI_DLEN_DATA_LENGTH(1);
 
-	if (p2wi->slave_addr >= 0 && addr != p2wi->slave_addr) {
+	if (p2wi->target_addr >= 0 && addr != p2wi->target_addr) {
 		dev_err(&adap->dev, "invalid P2WI address\n");
 		return -EINVAL;
 	}
@@ -188,7 +188,7 @@ static int p2wi_probe(struct platform_device *pdev)
 	unsigned long parent_clk_freq;
 	u32 clk_freq = I2C_MAX_STANDARD_MODE_FREQ;
 	struct p2wi *p2wi;
-	u32 slave_addr;
+	u32 target_addr;
 	int clk_div;
 	int irq;
 	int ret;
@@ -207,7 +207,7 @@ static int p2wi_probe(struct platform_device *pdev)
 	}
 
 	if (of_get_child_count(np) > 1) {
-		dev_err(dev, "P2WI only supports one slave device\n");
+		dev_err(dev, "P2WI only supports one target device\n");
 		return -EINVAL;
 	}
 
@@ -215,24 +215,24 @@ static int p2wi_probe(struct platform_device *pdev)
 	if (!p2wi)
 		return -ENOMEM;
 
-	p2wi->slave_addr = -1;
+	p2wi->target_addr = -1;
 
 	/*
 	 * Authorize a p2wi node without any children to be able to use an
 	 * i2c-dev from userpace.
 	 * In this case the slave_addr is set to -1 and won't be checked when
 	 * launching a P2WI transfer.
 	 */
 	childnp = of_get_next_available_child(np, NULL);
 	if (childnp) {
-		ret = of_property_read_u32(childnp, "reg", &slave_addr);
+		ret = of_property_read_u32(childnp, "reg", &target_addr);
 		if (ret) {
-			dev_err(dev, "invalid slave address on node %pOF\n",
+			dev_err(dev, "invalid target address on node %pOF\n",
 				childnp);
 			return -EINVAL;
 		}
 
-		p2wi->slave_addr = slave_addr;
+		p2wi->target_addr = target_addr;
 	}
 
 	p2wi->regs = devm_platform_ioremap_resource(pdev, 0);
@@ -10,7 +10,7 @@
  * data transfers. But, it differs from standard SMBus protocol on several
  * aspects:
- * - it supports only one slave device, and thus drop the address field
+ * - it supports only one target device, and thus drop the address field
  * - it adds a parity bit every 8bits of data
  * - only one read access is required to read a byte (instead of a write
@@ -215,24 +215,24 @@ static int p2wi_probe(struct platform_device *pdev)
 	 * Authorize a p2wi node without any children to be able to use an
 	 * i2c-dev from userpace.
-	 * In this case the slave_addr is set to -1 and won't be checked when
+	 * In this case the target_addr is set to -1 and won't be checked when
 	 * launching a P2WI transfer.
 	 */
-- 
2.43.0


^ permalink raw reply related	[flat|nested] 6+ messages in thread

* Re: [PATCH v2 48/60] i2c: sun6i-p2wi: reword according to newest specification
  2024-07-06 11:20 ` [PATCH v2 48/60] i2c: sun6i-p2wi: reword " Wolfram Sang
@ 2024-07-06 11:43   ` Chen-Yu Tsai
  2024-07-11 10:26   ` Andi Shyti
  1 sibling, 0 replies; 6+ messages in thread
From: Chen-Yu Tsai @ 2024-07-06 11:43 UTC (permalink / raw)
  To: Wolfram Sang
  Cc: linux-i2c, Andi Shyti, Jernej Skrabec, Samuel Holland,
	linux-sunxi, linux-kernel

On Sat, Jul 6, 2024 at 7:22 PM Wolfram Sang
<wsa+renesas@sang-engineering.com> wrote:
>
> Change the wording of this driver wrt. the newest I2C v7 and SMBus 3.2
> specifications and replace "master/slave" with more appropriate terms.
>
> Signed-off-by: Wolfram Sang <wsa+renesas@sang-engineering.com>

Acked-by: Chen-Yu Tsai <wens@csie.org>

> ---
>  drivers/i2c/busses/i2c-sun6i-p2wi.c | 20 ++++++++++----------
>  1 file changed, 10 insertions(+), 10 deletions(-)
>
> diff --git a/drivers/i2c/busses/i2c-sun6i-p2wi.c b/drivers/i2c/busses/i2c-sun6i-p2wi.c
> index 85e035e7a1d7..074eade6c4a4 100644
> --- a/drivers/i2c/busses/i2c-sun6i-p2wi.c
> +++ b/drivers/i2c/busses/i2c-sun6i-p2wi.c
> @@ -10,7 +10,7 @@
>   * The P2WI controller looks like an SMBus controller which only supports byte
>   * data transfers. But, it differs from standard SMBus protocol on several
>   * aspects:
> - * - it supports only one slave device, and thus drop the address field
> + * - it supports only one target device, and thus drop the address field
>   * - it adds a parity bit every 8bits of data
>   * - only one read access is required to read a byte (instead of a write
>   *   followed by a read access in standard SMBus protocol)
> @@ -88,7 +88,7 @@ struct p2wi {
>         void __iomem *regs;
>         struct clk *clk;
>         struct reset_control *rstc;
> -       int slave_addr;
> +       int target_addr;
>  };
>
>  static irqreturn_t p2wi_interrupt(int irq, void *dev_id)
> @@ -121,7 +121,7 @@ static int p2wi_smbus_xfer(struct i2c_adapter *adap, u16 addr,
>         struct p2wi *p2wi = i2c_get_adapdata(adap);
>         unsigned long dlen = P2WI_DLEN_DATA_LENGTH(1);
>
> -       if (p2wi->slave_addr >= 0 && addr != p2wi->slave_addr) {
> +       if (p2wi->target_addr >= 0 && addr != p2wi->target_addr) {
>                 dev_err(&adap->dev, "invalid P2WI address\n");
>                 return -EINVAL;
>         }
> @@ -188,7 +188,7 @@ static int p2wi_probe(struct platform_device *pdev)
>         unsigned long parent_clk_freq;
>         u32 clk_freq = I2C_MAX_STANDARD_MODE_FREQ;
>         struct p2wi *p2wi;
> -       u32 slave_addr;
> +       u32 target_addr;
>         int clk_div;
>         int irq;
>         int ret;
> @@ -207,7 +207,7 @@ static int p2wi_probe(struct platform_device *pdev)
>         }
>
>         if (of_get_child_count(np) > 1) {
> -               dev_err(dev, "P2WI only supports one slave device\n");
> +               dev_err(dev, "P2WI only supports one target device\n");
>                 return -EINVAL;
>         }
>
> @@ -215,24 +215,24 @@ static int p2wi_probe(struct platform_device *pdev)
>         if (!p2wi)
>                 return -ENOMEM;
>
> -       p2wi->slave_addr = -1;
> +       p2wi->target_addr = -1;
>
>         /*
>          * Authorize a p2wi node without any children to be able to use an
>          * i2c-dev from userpace.
> -        * In this case the slave_addr is set to -1 and won't be checked when
> +        * In this case the target_addr is set to -1 and won't be checked when
>          * launching a P2WI transfer.
>          */
>         childnp = of_get_next_available_child(np, NULL);
>         if (childnp) {
> -               ret = of_property_read_u32(childnp, "reg", &slave_addr);
> +               ret = of_property_read_u32(childnp, "reg", &target_addr);
>                 if (ret) {
> -                       dev_err(dev, "invalid slave address on node %pOF\n",
> +                       dev_err(dev, "invalid target address on node %pOF\n",
>                                 childnp);
>                         return -EINVAL;
>                 }
>
> -               p2wi->slave_addr = slave_addr;
> +               p2wi->target_addr = target_addr;
>         }
>
>         p2wi->regs = devm_platform_ioremap_resource(pdev, 0);
> --
> 2.43.0
>

^ permalink raw reply	[flat|nested] 6+ messages in thread

* Re: [PATCH v2 48/60] i2c: sun6i-p2wi: reword according to newest specification
  2024-07-06 11:20 ` [PATCH v2 48/60] i2c: sun6i-p2wi: reword " Wolfram Sang
  2024-07-06 11:43   ` Chen-Yu Tsai
@ 2024-07-11 10:26   ` Andi Shyti
  1 sibling, 0 replies; 6+ messages in thread
From: Andi Shyti @ 2024-07-11 10:26 UTC (permalink / raw)
  To: Wolfram Sang
  Cc: linux-i2c, Chen-Yu Tsai, Jernej Skrabec, Samuel Holland,
	linux-sunxi, linux-kernel

Hi Wolfram,

On Sat, Jul 06, 2024 at 01:20:48PM GMT, Wolfram Sang wrote:
> Change the wording of this driver wrt. the newest I2C v7 and SMBus 3.2
> specifications and replace "master/slave" with more appropriate terms.
> 
> Signed-off-by: Wolfram Sang <wsa+renesas@sang-engineering.com>

Reviewed-by: Andi Shyti <andi.shyti@kernel.org>

Thanks,
Andi

^ permalink raw reply	[flat|nested] 6+ messages in thread

* Re: [PATCH v2 00/60] i2c: reword first drivers according to newest specification
  2024-07-06 11:20 [PATCH v2 00/60] i2c: reword first drivers according to newest specification Wolfram Sang
  2024-07-06 11:20 ` [PATCH v2 48/60] i2c: sun6i-p2wi: reword " Wolfram Sang
@ 2024-07-11 13:16 ` Andi Shyti
  2024-07-11 14:45   ` Wolfram Sang
  1 sibling, 1 reply; 6+ messages in thread
From: Andi Shyti @ 2024-07-11 13:16 UTC (permalink / raw)
  To: Wolfram Sang
  Cc: linux-i2c, Ajay Gupta, Alain Volmat, Alexandre Torgue,
	Andreas Färber, Andrew Lunn, AngeloGioacchino Del Regno,
	asahi, Baolin Wang, Bartosz Golaszewski, Baruch Siach,
	Bence Csókás, Benson Leung, Binbin Zhou, Chen-Yu Tsai,
	Chris Brandt, Chris Packham, chrome-platform, Chunyan Zhang,
	Conghui Chen, Eddie James, Fabrizio Castro, Florian Fainelli,
	Gregory CLEMENT, Guenter Roeck, Hans de Goede, Hans Hu,
	Hector Martin, Heiko Stuebner, Jean Delvare, Jernej Skrabec,
	Jochen Friedrich, Jonathan Hunter, Kamal Dasu, Kunihiko Hayashi,
	linux-actions, linux-kernel, linux-mediatek, linux-mips,
	linuxppc-dev, linux-renesas-soc, linux-rockchip, linux-rpi-kernel,
	linux-stm32, linux-sunxi, linux-tegra, Manivannan Sadhasivam,
	Masami Hiramatsu, Matthias Brugger, Maxime Coquelin,
	Michael Ellerman, Michael Shych, openbmc, Orson Zhai,
	Patrice Chotard, Paul Cercueil, Peter Korsgaard,
	Pierre-Yves MORDRET, Ray Jui, Robert Richter, Samuel Holland,
	Scott Branden, Stefan Roese, Sven Peter, Thierry Reding,
	Thor Thayer, Till Harbaum, Vadim Pasternak, Viresh Kumar,
	virtualization, Vladimir Zapolskiy, Yicong Yang

Hi Wolfram,

pushed in i2c/i2c-host.

Thanks for this big work, at the end it turned out quite nice and
I'm happy of the outcome!

Thanks
Andi

On Sat, Jul 06, 2024 at 01:20:00PM GMT, Wolfram Sang wrote:
> Start changing the wording of the I2C main header wrt. the newest I2C
> v7 and SMBus 3.2 specifications and replace "master/slave" with more
> appropriate terms. This first step renames the members of struct
> i2c_algorithm. Once all in-tree users are converted, the anonymous union
> will go away again. All this work will also pave the way for finally
> seperating the monolithic header into more fine-grained headers like
> "i2c/clients.h" etc. So, this is not a simple renaming-excercise but
> also a chance to update the I2C core to recent Linux standards.
> 
> Changes since v1:
> 
> * changed wording according to the terminology we agreed on and defined
>   upstream. That means consistent use of "controller/target", and no
>   more "host/client". I added "local/remote target" where necessary.
> * added tags which I kept despite some changes in wording. The approach
>   and code changes (if necessary) did not change.
> * rebased to Andi's for-next branch
> * this series only contains patches which convert the drivers fully. If
>   all goes well, no more updates for them are needed. The previous
>   series converted all users of "master_xfer". But to avoid tons of
>   incremental patches to one driver, I will incrementally improve i2c.h
>   and see which drivers can be fully converted step-by-step.
> * do not mention I3C specs in commit messages, not really relevant here
> 
> Please note that I am not super strict with the 80 char limit. And, as
> agreed, I did not convert occasions where old terminology is used in
> register names or bits etc. or in function names outside of the I2C
> realm.
> 
> The outcome is that before this series 115 drivers use old terminology,
> after this only 54. Hooray.
> 
> And a comment to all janitors: Do not convert I2C drivers outside of
> drivers/i2c yet. Let us first gain experience here and present the
> well-tested results of what we figured out to other maintainers then.
> This ensures they have to deal with way less patch revisions.
> 
> Thanks and happy hacking!
> 
> 
> Wolfram Sang (60):
>   i2c: reword i2c_algorithm according to newest specification
>   i2c: ali15x3: reword according to newest specification
>   i2c: altera: reword according to newest specification
>   i2c: au1550: reword according to newest specification
>   i2c: bcm-kona: reword according to newest specification
>   i2c: bcm2835: reword according to newest specification
>   i2c: brcmstb: reword according to newest specification
>   i2c: cht-wc: reword according to newest specification
>   i2c: cp2615: reword according to newest specification
>   i2c: cros-ec-tunnel: reword according to newest specification
>   i2c: davinci: reword according to newest specification
>   i2c: digicolor: reword according to newest specification
>   i2c: diolan-u2c: reword according to newest specification
>   i2c: dln2: reword according to newest specification
>   i2c: fsi: reword according to newest specification
>   i2c: gpio: reword according to newest specification
>   i2c: highlander: reword according to newest specification
>   i2c: hisi: reword according to newest specification
>   i2c: hix5hd2: reword according to newest specification
>   i2c: i801: reword according to newest specification
>   i2c: ibm_iic: reword according to newest specification
>   i2c: iop3xx: reword according to newest specification
>   i2c: isch: reword according to newest specification
>   i2c: jz4780: reword according to newest specification
>   i2c: kempld: reword according to newest specification
>   i2c: ljca: reword according to newest specification
>   i2c: lpc2k: reword according to newest specification
>   i2c: ls2x: reword according to newest specification
>   i2c: mlxcpld: reword according to newest specification
>   i2c: mpc: reword according to newest specification
>   i2c: mt7621: reword according to newest specification
>   i2c: mv64xxx: reword according to newest specification
>   i2c: ocores: reword according to newest specification
>   i2c: octeon: reword according to newest specification
>   i2c: opal: reword according to newest specification
>   i2c: owl: reword according to newest specification
>   i2c: pasemi: reword according to newest specification
>   i2c: piix4: reword according to newest specification
>   i2c: powermac: reword according to newest specification
>   i2c: pxa-pci: reword according to newest specification
>   i2c: riic: reword according to newest specification
>   i2c: rk3x: reword according to newest specification
>   i2c: robotfuzz-osif: reword according to newest specification
>   i2c: rzv2m: reword according to newest specification
>   i2c: sis5595: reword according to newest specification
>   i2c: sprd: reword according to newest specification
>   i2c: stm32f4: reword according to newest specification
>   i2c: sun6i-p2wi: reword according to newest specification
>   i2c: taos-evm: reword according to newest specification
>   i2c: tegra-bpmp: reword according to newest specification
>   i2c: thunderx-pcidrv: reword according to newest specification
>   i2c: tiny-usb: reword according to newest specification
>   i2c: uniphier-f: reword according to newest specification
>   i2c: uniphier: reword according to newest specification
>   i2c: viperboard: reword according to newest specification
>   i2c: viai2c: reword according to newest specification
>   i2c: nvidia-gpu: reword according to newest specification
>   i2c: virtio: reword according to newest specification
>   i2c: cpm: reword according to newest specification
>   i2c: st: reword according to newest specification
> 
>  drivers/i2c/busses/i2c-ali15x3.c         |  2 +-
>  drivers/i2c/busses/i2c-altera.c          |  4 +-
>  drivers/i2c/busses/i2c-au1550.c          | 15 +++----
>  drivers/i2c/busses/i2c-bcm-kona.c        | 13 +++---
>  drivers/i2c/busses/i2c-bcm2835.c         | 10 ++---
>  drivers/i2c/busses/i2c-brcmstb.c         | 11 +++--
>  drivers/i2c/busses/i2c-cht-wc.c          |  8 ++--
>  drivers/i2c/busses/i2c-cp2615.c          |  8 ++--
>  drivers/i2c/busses/i2c-cpm.c             |  4 +-
>  drivers/i2c/busses/i2c-cros-ec-tunnel.c  |  4 +-
>  drivers/i2c/busses/i2c-davinci.c         | 17 ++++---
>  drivers/i2c/busses/i2c-digicolor.c       |  6 +--
>  drivers/i2c/busses/i2c-diolan-u2c.c      |  2 +-
>  drivers/i2c/busses/i2c-dln2.c            |  4 +-
>  drivers/i2c/busses/i2c-fsi.c             | 56 ++++++++++++------------
>  drivers/i2c/busses/i2c-gpio.c            |  8 ++--
>  drivers/i2c/busses/i2c-highlander.c      |  2 +-
>  drivers/i2c/busses/i2c-hisi.c            |  8 ++--
>  drivers/i2c/busses/i2c-hix5hd2.c         |  6 +--
>  drivers/i2c/busses/i2c-i801.c            | 12 ++---
>  drivers/i2c/busses/i2c-ibm_iic.c         | 27 +++++-------
>  drivers/i2c/busses/i2c-iop3xx.c          | 15 +++----
>  drivers/i2c/busses/i2c-isch.c            |  2 +-
>  drivers/i2c/busses/i2c-jz4780.c          |  4 +-
>  drivers/i2c/busses/i2c-kempld.c          |  4 +-
>  drivers/i2c/busses/i2c-ljca.c            | 20 ++++-----
>  drivers/i2c/busses/i2c-lpc2k.c           | 10 ++---
>  drivers/i2c/busses/i2c-ls2x.c            | 11 +++--
>  drivers/i2c/busses/i2c-mlxcpld.c         | 14 +++---
>  drivers/i2c/busses/i2c-mpc.c             |  4 +-
>  drivers/i2c/busses/i2c-mt7621.c          | 26 +++++------
>  drivers/i2c/busses/i2c-mv64xxx.c         | 12 ++---
>  drivers/i2c/busses/i2c-nvidia-gpu.c      |  7 ++-
>  drivers/i2c/busses/i2c-ocores.c          |  8 ++--
>  drivers/i2c/busses/i2c-octeon-core.c     |  6 +--
>  drivers/i2c/busses/i2c-octeon-core.h     |  4 +-
>  drivers/i2c/busses/i2c-octeon-platdrv.c  |  2 +-
>  drivers/i2c/busses/i2c-opal.c            | 10 ++---
>  drivers/i2c/busses/i2c-owl.c             | 12 ++---
>  drivers/i2c/busses/i2c-pasemi-core.c     |  6 +--
>  drivers/i2c/busses/i2c-piix4.c           |  2 +-
>  drivers/i2c/busses/i2c-powermac.c        | 14 +++---
>  drivers/i2c/busses/i2c-pxa-pci.c         |  2 +-
>  drivers/i2c/busses/i2c-riic.c            |  8 ++--
>  drivers/i2c/busses/i2c-rk3x.c            | 20 ++++-----
>  drivers/i2c/busses/i2c-robotfuzz-osif.c  |  4 +-
>  drivers/i2c/busses/i2c-rzv2m.c           | 12 ++---
>  drivers/i2c/busses/i2c-sis5595.c         |  2 +-
>  drivers/i2c/busses/i2c-sprd.c            | 16 +++----
>  drivers/i2c/busses/i2c-st.c              |  8 ++--
>  drivers/i2c/busses/i2c-stm32f4.c         |  8 ++--
>  drivers/i2c/busses/i2c-sun6i-p2wi.c      | 20 ++++-----
>  drivers/i2c/busses/i2c-taos-evm.c        |  2 +-
>  drivers/i2c/busses/i2c-tegra-bpmp.c      |  4 +-
>  drivers/i2c/busses/i2c-thunderx-pcidrv.c |  2 +-
>  drivers/i2c/busses/i2c-tiny-usb.c        |  6 +--
>  drivers/i2c/busses/i2c-uniphier-f.c      | 26 +++++------
>  drivers/i2c/busses/i2c-uniphier.c        | 15 +++----
>  drivers/i2c/busses/i2c-viai2c-common.c   |  2 +-
>  drivers/i2c/busses/i2c-viai2c-wmt.c      |  8 ++--
>  drivers/i2c/busses/i2c-viai2c-zhaoxin.c  | 12 ++---
>  drivers/i2c/busses/i2c-viperboard.c      | 10 ++---
>  drivers/i2c/busses/i2c-virtio.c          |  2 +-
>  include/linux/i2c.h                      | 24 +++++++---
>  64 files changed, 313 insertions(+), 320 deletions(-)
> 
> -- 
> 2.43.0
> 

^ permalink raw reply	[flat|nested] 6+ messages in thread

* Re: [PATCH v2 00/60] i2c: reword first drivers according to newest specification
  2024-07-11 13:16 ` [PATCH v2 00/60] i2c: reword first drivers " Andi Shyti
@ 2024-07-11 14:45   ` Wolfram Sang
  0 siblings, 0 replies; 6+ messages in thread
From: Wolfram Sang @ 2024-07-11 14:45 UTC (permalink / raw)
  To: Andi Shyti
  Cc: linux-i2c, Ajay Gupta, Alain Volmat, Alexandre Torgue,
	Andreas Färber, Andrew Lunn, AngeloGioacchino Del Regno,
	asahi, Baolin Wang, Bartosz Golaszewski, Baruch Siach,
	Bence Csókás, Benson Leung, Binbin Zhou, Chen-Yu Tsai,
	Chris Brandt, Chris Packham, chrome-platform, Chunyan Zhang,
	Conghui Chen, Eddie James, Fabrizio Castro, Florian Fainelli,
	Gregory CLEMENT, Guenter Roeck, Hans de Goede, Hans Hu,
	Hector Martin, Heiko Stuebner, Jean Delvare, Jernej Skrabec,
	Jochen Friedrich, Jonathan Hunter, Kamal Dasu, Kunihiko Hayashi,
	linux-actions, linux-kernel, linux-mediatek, linux-mips,
	linuxppc-dev, linux-renesas-soc, linux-rockchip, linux-rpi-kernel,
	linux-stm32, linux-sunxi, linux-tegra, Manivannan Sadhasivam,
	Masami Hiramatsu, Matthias Brugger, Maxime Coquelin,
	Michael Ellerman, Michael Shych, openbmc, Orson Zhai,
	Patrice Chotard, Paul Cercueil, Peter Korsgaard,
	Pierre-Yves MORDRET, Ray Jui, Robert Richter, Samuel Holland,
	Scott Branden, Stefan Roese, Sven Peter, Thierry Reding,
	Thor Thayer, Till Harbaum, Vadim Pasternak, Viresh Kumar,
	virtualization, Vladimir Zapolskiy, Yicong Yang

[-- Attachment #1: Type: text/plain, Size: 148 bytes --]


> Thanks for this big work, at the end it turned out quite nice and
> I'm happy of the outcome!

Me too. And thanks for the enormous review work!


[-- Attachment #2: signature.asc --]
[-- Type: application/pgp-signature, Size: 833 bytes --]

^ permalink raw reply	[flat|nested] 6+ messages in thread

end of thread, other threads:[~2024-07-11 14:45 UTC | newest]

Thread overview: 6+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2024-07-06 11:20 [PATCH v2 00/60] i2c: reword first drivers according to newest specification Wolfram Sang
2024-07-06 11:20 ` [PATCH v2 48/60] i2c: sun6i-p2wi: reword " Wolfram Sang
2024-07-06 11:43   ` Chen-Yu Tsai
2024-07-11 10:26   ` Andi Shyti
2024-07-11 13:16 ` [PATCH v2 00/60] i2c: reword first drivers " Andi Shyti
2024-07-11 14:45   ` Wolfram Sang

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox